==> deepin-boot-maker_6.0.1.tar.xz: BUILD/src/translations/deepin-boot-maker_lv.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lv" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu pārformatējiet to vai Drošības Centrā atspējojiet &quot;Automātiski skenēt USB datu glabāšanas ierīces&quot;</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu pārformatējiet to</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Iekšēja Kļūda</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Boot Maker ir rīks sistēmas atpoguļojuma ierakstīšanai USB un citos datu nesējos</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>Vilkt ISO failu šeit</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>VAI</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>Atlasīt ISO failu</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>Talāk</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>Atlasīt vēlreiz ISO failu</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>Neatļauts ISO fails</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Detektējam ISO failu, lūdzu uzgaidiet...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>Ieraksta</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>Ieraksta, lūdzu uzgaidiet...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Ieakstīšanas laikā neatvienojiet disku un neizslēdziet datoru</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Atvienojams Disks</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>Atvienojams Disks</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>Restartēt tagad</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>Veiksmīgi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Pabeigts</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>Nosūtīt atsauksmi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>Pēc Pārdošanas Pakalpojumi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Aizvērt</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>Piedodiet, process neizdevās</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>Process neizdevās</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Pārbauda datus un droši atvieno datu nesēju, lūdzu uzgaidiet...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>Atlasīt partīciju</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>Formatēt partīciju</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>Sākt</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Formatēšana izdzēsis visus partīcijas datus, bet var palielināt veiksmīgas ierakstīšanas iespēju. Lūdzu apstipriniet pirms turpinām</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Labi</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atcelt</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Partīcijas formatēšana parrakstīs visus datus, lūdzu izveidojiet datu rezerves kopiju pirms turpiniet</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu formatējiet partīciju FAT32 formātā</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>Nav pieejams neviens disks</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atpakaļ</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>Formatēt partīciju</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_6.0.8.tar.xz: BUILD/src/translations/deepin-boot-maker_lv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lv">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="20"/>
        <source>Disk Format Error: Please reformat it or disable "Auto scan USB storage devices" in Security Center</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu pārformatējiet to vai Drošības Centrā atspējojiet "Automātiski skenēt USB datu glabāšanas ierīces"</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="23"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu pārformatējiet to</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="28"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="31"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="34"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="37"/>
        <source>Internal Error</source>
        <translation>Iekšēja Kļūda</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="69"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Boot Maker ir rīks sistēmas atpoguļojuma ierakstīšanai USB un citos datu nesējos</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="71"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="114"/>
        <source>Drag an ISO image file here</source>
        <translation>Vilkt ISO failu šeit</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>OR</source>
        <translation>VAI</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="80"/>
        <source>Select an ISO image file</source>
        <translation>Atlasīt ISO failu</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="171"/>
        <source>Next</source>
        <translation>Talāk</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="231"/>
        <source>Reselect an ISO image file</source>
        <translation>Atlasīt vēlreiz ISO failu</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="191"/>
        <source>Illegal ISO image file</source>
        <translation>Neatļauts ISO fails</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="378"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Detektējam ISO failu, lūdzu uzgaidiet...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="34"/>
        <source>Burning</source>
        <translation>Ieraksta</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="46"/>
        <source>Burning, please wait...</source>
        <translation>Ieraksta, lūdzu uzgaidiet...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Ieakstīšanas laikā neatvienojiet disku un neizslēdziet datoru</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="68"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="23"/>
        <source>Removable Disk</source>
        <translation>Atvienojams Disks</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="227"/>
        <source>Removable disk</source>
        <translation>Atvienojams Disks</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="105"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="88"/>
        <source>Reboot now</source>
        <translation>Restartēt tagad</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Successful</source>
        <translation>Veiksmīgi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Pabeigts</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="174"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="175"/>
        <source>Submit Feedback</source>
        <translation>Nosūtīt atsauksmi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="198"/>
        <source>After-Sale Services</source>
        <translation>Pēc Pārdošanas Pakalpojumi</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="213"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Aizvērt</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="222"/>
        <source>Sorry, process failed</source>
        <translation>Piedodiet, process neizdevās</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="17"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Pārbauda datus un droši atvieno datu nesēju, lūdzu uzgaidiet...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="75"/>
        <source>Select a partition</source>
        <translation>Atlasīt partīciju</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="101"/>
        <source>Format the partition</source>
        <translation>Formatēt partīciju</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="154"/>
        <source>Start</source>
        <translation>Sākt</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="223"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Formatēšana izdzēsis visus partīcijas datus, bet var palielināt veiksmīgas ierakstīšanas iespēju. Lūdzu apstipriniet pirms turpinām</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="378"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Labi</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="385"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atcelt</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Partīcijas formatēšana parrakstīs visus datus, lūdzu izveidojiet datu rezerves kopiju pirms turpiniet</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="404"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Diska Formatēšanas Kļūda: Lūdzu formatējiet partīciju FAT32 formātā</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="137"/>
        <source>No disk available</source>
        <translation>Nav pieejams neviens disks</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="158"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atpakaļ</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <source>Format Partition</source>
        <translation>Formatēt partīciju</translation>
    </message>
</context>
</TS>
